@@ -200,6 +200,7 @@ create_expectations_data_frame <- function(data, name = NULL, indentation = 0,
   column_expectations <- plyr::llply(colnames(data), function(col_name) {
     # Get current column
     current_col <- data[[col_name]]
+
     if (is.list(current_col)) {
       return(NULL)
     }
@@ -225,14 +226,16 @@ create_expectations_data_frame <- function(data, name = NULL, indentation = 0,
     }
 
     # Create expect_equal text
-    create_expect_equal(x, y,
-                        add_tolerance = is.numeric(current_col),
-                        add_fixed = is.character(current_col),
-                        spaces = 2,
-                        tolerance = tolerance)
+    create_expect_equal(
+      x, y,
+      add_tolerance = is.numeric(current_col),
+      add_fixed = is.character(current_col),
+      spaces = 2,
+      tolerance = tolerance)
   })
 
   null_indices <- get_null_indices(column_expectations)
+
   if (length(null_indices) > 0) {
 
     # Warn about skipped elements
@@ -542,7 +545,7 @@ create_expectations_vector <- function(data, name = NULL, indentation = 0,
         "null"
       )
     ) &&
-    !any(element_lengths(data, length) > 1)
+    !any(element_lengths(data) > 1)
 
   all_uniquely_named <- checkmate::test_list(x = as.list(data), names = "unique")
 
@@ -708,6 +711,7 @@ create_expectations_vector <- function(data, name = NULL, indentation = 0,
 
 
 create_expectations_side_effect <- function(side_effects, name = NULL,
+                                            copy_env = FALSE,
                                             indentation = 0, strip = TRUE,
                                             add_comments = TRUE, test_id = 10000) {
 
@@ -734,6 +738,9 @@ create_expectations_side_effect <- function(side_effects, name = NULL,
   checkmate::assert_flag(
     x = strip, add = assert_collection
   )
+  checkmate::assert_flag(
+    x = copy_env, add = assert_collection
+  )
   checkmate::reportAssertions(assert_collection)
   # End of argument checks ####
 
@@ -744,9 +751,11 @@ create_expectations_side_effect <- function(side_effects, name = NULL,
   call_name <- name
   name <- create_output_var_name("side_effects_", test_id)
 
+  copy_env_string <- ifelse(isTRUE(copy_env), ", copy_env = TRUE", "")
+
   # Create assignment string
   assign_string <- create_assignment_strings(
-    call_name = paste0("xpectr::capture_side_effects(", call_name, ", reset_seed = TRUE)"),
+    call_name = paste0("xpectr::capture_side_effects(", call_name, copy_env_string, ", reset_seed = TRUE)"),
     new_name = name,
     evaluate_once = TRUE,
     comment = "# Assigning side effects")
